@@ -1,4 +1,4 @@
-// Copyright (c) 2014-2019 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <cassert>
@@ -13,9 +13,9 @@
 // Include the analyze function that checks
 // a grammar for possible infinite cycles.
 
-#include <tao/pegtl/analyze.hpp>
+#include <tao/pegtl/contrib/analyze.hpp>
 
-namespace pegtl = tao::TAO_PEGTL_NAMESPACE;
+namespace pegtl = TAO_PEGTL_NAMESPACE;
 
 namespace calculator
 {
@@ -168,10 +168,10 @@ namespace calculator
       void insert( const std::string& name, const order p, const std::function< long( long, long ) >& f )
       {
          assert( !name.empty() );
-         m_ops.insert( { name, { p, f } } );
+         m_ops.try_emplace( name, op{ p, f } );
       }
 
-      const std::map< std::string, op >& ops() const
+      [[nodiscard]] const std::map< std::string, op >& ops() const noexcept
       {
          return m_ops;
       }
@@ -182,14 +182,13 @@ namespace calculator
 
    // Here the actual grammar starts.
 
-   using namespace tao::pegtl;  // NOLINT
+   using namespace tao::pegtl;
 
    // Comments are introduced by a '#' and proceed to the end-of-line/file.
 
    struct comment
-      : if_must< one< '#' >, until< eolf > >
-   {
-   };
+      : seq< one< '#' >, until< eolf > >
+   {};
 
    // The calculator ignores all spaces and comments; space is a pegtl rule
    // that matches the usual ascii characters ' ', '\t', '\n' etc. In other
@@ -197,8 +196,7 @@ namespace calculator
 
    struct ignored
       : sor< space, comment >
-   {
-   };
+   {};
 
    // Since the binary operators are taken from a runtime data structure
    // (rather than hard-coding them into the grammar), we need a custom
@@ -207,7 +205,7 @@ namespace calculator
 
    struct infix
    {
-      using analyze_t = analysis::generic< analysis::rule_type::any >;
+      using rule_t = ascii::any::rule_t;
 
       template< apply_mode,
                 rewind_mode,
@@ -215,9 +213,9 @@ namespace calculator
                 class Action,
                 template< typename... >
                 class Control,
-                typename Input,
+                typename ParseInput,
                 typename... States >
-      static bool match( Input& in, const operators& b, stacks& s, States&&... /*unused*/ )
+      static bool match( ParseInput& in, const operators& b, stacks& s, States&&... /*unused*/ )
       {
          // Look for the longest match of the input against the operators in the operator map.
 
@@ -225,8 +223,8 @@ namespace calculator
       }
 
    private:
-      template< typename Input >
-      static bool match( Input& in, const operators& b, stacks& s, std::string t )
+      template< typename ParseInput >
+      static bool match( ParseInput& in, const operators& b, stacks& s, std::string t )
       {
          if( in.size( t.size() + 1 ) > t.size() ) {
             t += in.peek_char( t.size() );
@@ -249,12 +247,11 @@ namespace calculator
       }
    };
 
-   // A number is a non-empty sequence of digits preceeded by an optional sign.
+   // A number is a non-empty sequence of digits preceded by an optional sign.
 
    struct number
       : seq< opt< one< '+', '-' > >, plus< digit > >
-   {
-   };
+   {};
 
    struct expression;
 
@@ -262,41 +259,38 @@ namespace calculator
    // proceed with an expression and a ')'.
 
    struct bracket
-      : if_must< one< '(' >, expression, one< ')' > >
-   {
-   };
+      : seq< one< '(' >, expression, one< ')' > >
+   {};
 
    // An atomic expression, i.e. one without operators, is either a number or
    // a bracketed expression.
 
    struct atomic
       : sor< number, bracket >
-   {
-   };
+   {};
 
    // An expression is a non-empty list of atomic expressions where each pair
    // of atomic expressions is separated by an infix operator and we allow
-   // the rule ignored as padding (before and after every singlar expression).
+   // the rule ignored as padding (before and after every single expression).
 
    struct expression
       : list< atomic, infix, ignored >
-   {
-   };
+   {};
 
    // The top-level grammar allows one expression and then expects eof.
 
    struct grammar
-      : must< expression, eof >
-   {
-   };
+      : seq< expression, eof >
+   {};
 
    // After the grammar we proceed with the additional actions that are
    // required to let our calculator actually do something.
 
+   // The base-case of the class template for the actions, does nothing.
+
    template< typename Rule >
    struct action
-   {
-   };
+   {};
 
    // This action will be called when the number rule matches; it converts the
    // matched portion of the input to a long and pushes it onto the operand
@@ -305,8 +299,8 @@ namespace calculator
    template<>
    struct action< number >
    {
-      template< typename Input >
-      static void apply( const Input& in, const operators& /*unused*/, stacks& s )
+      template< typename ActionInput >
+      static void apply( const ActionInput& in, const operators& /*unused*/, stacks& s )
       {
          std::stringstream ss( in.string() );
          long v;
@@ -338,11 +332,13 @@ namespace calculator
 
 }  // namespace calculator
 
-int main( int argc, char** argv )
+int main( int argc, char** argv )  // NOLINT(bugprone-exception-escape)
 {
    // Check the grammar for some possible issues.
 
-   pegtl::analyze< calculator::grammar >();
+   if( pegtl::analyze< calculator::grammar >() != 0 ) {
+      return 1;
+   }
 
    // The objects required as state by the actions.
 
@@ -351,13 +347,14 @@ int main( int argc, char** argv )
 
    for( int i = 1; i < argc; ++i ) {
       // Parse and process the command-line arguments as calculator expressions...
-
-      pegtl::argv_input<> in( argv, i );
-      pegtl::parse< calculator::grammar, calculator::action >( in, b, s );
-
-      // ...and print the respective results to std::cout.
-
-      std::cout << s.finish() << std::endl;
+      pegtl::argv_input in( argv, i );
+      if( pegtl::parse< calculator::grammar, calculator::action >( in, b, s ) ) {
+         // ...and print the respective results to std::cout.
+         std::cout << s.finish() << std::endl;
+      }
+      else {
+         std::cerr << "parse error for: " << argv[ i ] << std::endl;
+      }
    }
    return 0;
 }
