@@ -1,4 +1,4 @@
-// Copyright (c) 2016-2020 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2016-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <cassert>
@@ -10,7 +10,7 @@
 
 #include <tao/pegtl.hpp>
 
-namespace pegtl = tao::TAO_PEGTL_NAMESPACE;
+namespace pegtl = TAO_PEGTL_NAMESPACE;
 
 namespace csv1
 {
@@ -30,8 +30,8 @@ namespace csv1
    // clang-format off
    struct value : pegtl::plus< pegtl::digit > {};
    struct value_item : pegtl::pad< value, pegtl::blank > {};
-   struct value_list : pegtl::list_must< value_item, pegtl::one< ',' > > {};
-   struct value_line : pegtl::if_must< value_list, pegtl::eolf > {};
+   struct value_list : pegtl::list< value_item, pegtl::one< ',' > > {};
+   struct value_line : pegtl::seq< value_list, pegtl::eolf > {};
    struct comment_line : pegtl::seq< pegtl::one< '#' >, pegtl::until< pegtl::eolf > > {};
    struct line : pegtl::sor< comment_line, value_line > {};
    struct file : pegtl::until< pegtl::eof, line > {};
@@ -45,14 +45,13 @@ namespace csv1
 
    template< typename Rule >
    struct action
-   {
-   };
+   {};
 
    template<>
    struct action< value >
    {
-      template< typename Input >
-      static void apply( const Input& in, result_data& data )
+      template< typename ActionInput >
+      static void apply( const ActionInput& in, result_data& data )
       {
          assert( !data.empty() );
          std::stringstream ss( in.string() );
@@ -65,21 +64,20 @@ namespace csv1
    template< typename Rule >
    struct control
       : pegtl::normal< Rule >
-   {
-   };
+   {};
 
    template<>
    struct control< value_line >
       : pegtl::normal< value_line >
    {
-      template< typename Input >
-      static void start( Input& /*unused*/, result_data& data )
+      template< typename ParseInput >
+      static void start( ParseInput& /*unused*/, result_data& data )
       {
          data.emplace_back();
       }
 
-      template< typename Input >
-      static void failure( Input& /*unused*/, result_data& data )
+      template< typename ParseInput >
+      static void failure( ParseInput& /*unused*/, result_data& data )
       {
          assert( !data.empty() );
          data.pop_back();
@@ -88,12 +86,15 @@ namespace csv1
 
 }  // namespace csv1
 
-int main( int argc, char** argv )  // NOLINT
+int main( int argc, char** argv )  // NOLINT(bugprone-exception-escape)
 {
    for( int i = 1; i < argc; ++i ) {
-      pegtl::file_input<> in( argv[ i ] );
+      pegtl::file_input in( argv[ i ] );
       csv1::result_data data;
-      pegtl::parse< pegtl::must< csv1::file >, csv1::action, csv1::control >( in, data );
+      if( !pegtl::parse< pegtl::seq< csv1::file >, csv1::action, csv1::control >( in, data ) ) {
+         std::cerr << "parse error" << std::endl;
+         return 1;
+      }
       for( const auto& line : data ) {
          assert( !line.empty() );  // The grammar doesn't allow empty lines.
          std::cout << line.front();
