@@ -1,12 +1,13 @@
-// Copyright (c) 2016-2020 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2016-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
+#include <exception>
 #include <iostream>
 #include <utility>
 
 #include <tao/pegtl.hpp>
 
-namespace pegtl = tao::TAO_PEGTL_NAMESPACE;
+namespace pegtl = TAO_PEGTL_NAMESPACE;
 
 namespace csv2
 {
@@ -25,10 +26,10 @@ namespace csv2
    // clang-format off
    template< char C > struct string_without : pegtl::star< pegtl::not_one< C, 10, 13 > > {};
    struct plain_value : string_without< ',' > {};
-   struct quoted_value : pegtl::if_must< pegtl::one< '"' >, string_without< '"' >, pegtl::one< '"' > > {};
+   struct quoted_value : pegtl::seq< pegtl::one< '"' >, string_without< '"' >, pegtl::one< '"' > > {};
    struct value : pegtl::sor< quoted_value, plain_value > {};
    template< unsigned N > struct line : pegtl::seq< value, pegtl::rep< N - 1, pegtl::one< ',' >, value >, pegtl::eol > {};
-   template< unsigned N > struct file : pegtl::until< pegtl::eof, line< N > > { static_assert( N, "N must be positive" ); };
+   template< unsigned N > struct file : pegtl::until< pegtl::eof, line< N > > { static_assert( N != 0 ); };
    // clang-format on
 
    // Meta-programming helper:
@@ -86,14 +87,13 @@ namespace csv2
 
    template< typename Rule >
    struct action
-   {
-   };
+   {};
 
    template<>
    struct action< plain_value >
    {
-      template< typename Input, unsigned N >
-      static void apply( const Input& in, result_data< N >& data )
+      template< typename ActionInput, unsigned N >
+      static void apply( const ActionInput& in, result_data< N >& data )
       {
          data.temp.push_back( in.string() );
       }
@@ -102,19 +102,19 @@ namespace csv2
    template<>
    struct action< string_without< '"' > >
       : action< plain_value >
-   {
-   };
+   {};
 
    template< unsigned N >
    struct action< line< N > >
    {
       using tuple_t = typename tuple_help< N, std::tuple<> >::tuple_t;
 
-      template< typename Input >
-      static void apply( const Input& in, result_data< N >& data )
+      template< typename ActionInput >
+      static void apply( const ActionInput& in, result_data< N >& data )
       {
          if( data.temp.size() != N ) {
-            throw pegtl::parse_error( "column count mismatch", in );
+            std::cerr << "column count mismatch " << in.position() << std::endl;
+            std::terminate();
          }
          tuple_t temp;
          tuple_init< N - 1 >::init( temp, data.temp );
@@ -170,15 +170,19 @@ namespace csv2
 
 }  // namespace csv2
 
-int main( int argc, char** argv )  // NOLINT
+int main( int argc, char** argv )  // NOLINT(bugprone-exception-escape)
 {
    for( int i = 1; i < argc; ++i ) {
-      pegtl::file_input<> in( argv[ i ] );
+      pegtl::file_input in( argv[ i ] );
       constexpr unsigned number_of_columns = 3;
       csv2::result_data< number_of_columns > data;
-      pegtl::parse< pegtl::must< csv2::file< number_of_columns > >, csv2::action >( in, data );
-      for( const auto& line : data.result ) {
-         csv2::print_tuple( line );
+      if( pegtl::parse< pegtl::seq< csv2::file< number_of_columns > >, csv2::action >( in, data ) ) {
+         for( const auto& line : data.result ) {
+            csv2::print_tuple( line );
+         }
+      }
+      else {
+         std::cerr << "parse error" << std::endl;
       }
    }
    return 0;
