@@ -1,7 +1,7 @@
-// Copyright (c) 2014-2020 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
-#ifndef TAO_PEGTL_SRC_EXAMPLES_PEGTL_JSON_CLASSES_HPP  // NOLINT
+#ifndef TAO_PEGTL_SRC_EXAMPLES_PEGTL_JSON_CLASSES_HPP
 #define TAO_PEGTL_SRC_EXAMPLES_PEGTL_JSON_CLASSES_HPP
 
 #include <iostream>
@@ -10,7 +10,7 @@
 #include <string>
 #include <vector>
 
-namespace examples
+namespace example
 {
    enum class json_type
    {
@@ -27,8 +27,7 @@ namespace examples
    protected:
       explicit json_base( const json_type in_type )
          : type( in_type )
-      {
-      }
+      {}
 
       virtual ~json_base() = default;
 
@@ -36,8 +35,8 @@ namespace examples
       json_base( const json_base& ) = delete;
       json_base( json_base&& ) = delete;
 
-      void operator=( const json_base& ) = delete;
-      void operator=( json_base&& ) = delete;
+      json_base& operator=( const json_base& ) = delete;
+      json_base& operator=( json_base&& ) = delete;
 
       virtual void stream( std::ostream& ) const = 0;
 
@@ -60,8 +59,7 @@ namespace examples
    {
       array_json()
          : json_base( json_type::array )
-      {
-      }
+      {}
 
       std::vector< std::shared_ptr< json_base > > data;
 
@@ -85,8 +83,7 @@ namespace examples
       explicit boolean_json( const bool in_data )
          : json_base( json_type::boolean ),
            data( in_data )
-      {
-      }
+      {}
 
       bool data;
 
@@ -101,8 +98,7 @@ namespace examples
    {
       null_json()
          : json_base( json_type::null )
-      {
-      }
+      {}
 
       void stream( std::ostream& o ) const override
       {
@@ -116,8 +112,7 @@ namespace examples
       explicit number_json( const long double in_data )
          : json_base( json_type::number ),
            data( in_data )
-      {
-      }
+      {}
 
       long double data;
 
@@ -135,7 +130,7 @@ namespace examples
 
       static const char* h = "0123456789abcdef";
 
-      const auto* d = static_cast< const unsigned char* >( static_cast< const void* >( data.data() ) );
+      const auto* d = reinterpret_cast< const unsigned char* >( data.data() );
 
       for( std::size_t i = 0; i < data.size(); ++i ) {
          switch( const auto c = d[ i ] ) {
@@ -178,11 +173,10 @@ namespace examples
    struct string_json
       : public json_base
    {
-      explicit string_json( const std::string& in_data )  // NOLINT
+      explicit string_json( const std::string& in_data )
          : json_base( json_type::string ),
            data( in_data )
-      {
-      }
+      {}
 
       std::string data;
 
@@ -197,8 +191,7 @@ namespace examples
    {
       object_json()
          : json_base( json_type::object )
-      {
-      }
+      {}
 
       std::map< std::string, std::shared_ptr< json_base > > data;
 
@@ -216,6 +209,6 @@ namespace examples
       }
    };
 
-}  // namespace examples
+}  // namespace example
 
 #endif
