@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2020 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2017-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <type_traits>
@@ -6,7 +6,7 @@
 #include <tao/pegtl.hpp>
 #include <tao/pegtl/contrib/parse_tree.hpp>
 
-using namespace tao::TAO_PEGTL_NAMESPACE;  // NOLINT
+using namespace TAO_PEGTL_NAMESPACE;
 
 template< typename >
 using selector = std::true_type;
@@ -21,14 +21,14 @@ struct work
 template<>
 struct work< success >
 {
-   template< typename Input >
-   static void apply( const Input& /*unused*/, user_state& /*unused*/ )
+   template< typename ActionInput >
+   static void apply( const ActionInput& /*unused*/, user_state& /*unused*/ )
    {}
 };
 
 int main()
 {
-   memory_input<> input( "", "dummy" );
+   memory_input input( "", "dummy" );
 
    user_state state;
    auto root = parse_tree::parse< success, selector, work >( input, state );
