@@ -1,6 +1,15 @@
-// Copyright (c) 2018-2020 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2018-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
+#if !defined( __cpp_exceptions )
+#include <iostream>
+int main()
+{
+   std::cerr << "Exception support required, example unavailable." << std::endl;
+   return 1;
+}
+#else
+
 #include <cstring>
 #include <iostream>
 #include <map>
@@ -10,7 +19,7 @@
 
 #include <tao/pegtl/contrib/integer.hpp>
 
-namespace pegtl = tao::TAO_PEGTL_NAMESPACE;
+namespace pegtl = TAO_PEGTL_NAMESPACE;
 
 namespace example
 {
@@ -43,21 +52,23 @@ namespace example
 
    template< typename Rule >
    struct action
-   {
-   };
+   {};
 
    template<>
    struct action< value >
-      : public pegtl::integer::unsigned_action
    {
-      // Sets st.converted to the integer value of the matched string.
+      template< typename ActionInput >
+      static void apply( const ActionInput& in, state& st )
+      {
+         pegtl::unsigned_action::apply( in, st.converted );
+      }
    };
 
    template<>
    struct action< name >
    {
-      template< typename Input >
-      static void apply( const Input& in, state& st )
+      template< typename ActionInput >
+      static void apply( const ActionInput& in, state& st )
       {
          st.temporary = in.string();
       }
@@ -66,11 +77,11 @@ namespace example
    template<>
    struct action< definition >
    {
-      template< typename Input >
-      static void apply( const Input& in, state& st )
+      template< typename ActionInput >
+      static void apply( const ActionInput& in, state& st )
       {
-         if( !st.symbol_table.insert( { st.temporary, 0 } ).second ) {
-            throw pegtl::parse_error( "duplicate symbol " + st.temporary, in );  // NOLINT
+         if( !st.symbol_table.try_emplace( st.temporary, 0 ).second ) {
+            throw pegtl::parse_error( "duplicate symbol " + st.temporary, in );
          }
       }
    };
@@ -78,12 +89,12 @@ namespace example
    template<>
    struct action< assignment >
    {
-      template< typename Input >
-      static void apply( const Input& in, state& st )
+      template< typename ActionInput >
+      static void apply( const ActionInput& in, state& st )
       {
          const auto i = st.symbol_table.find( st.temporary );
          if( i == st.symbol_table.end() ) {
-            throw pegtl::parse_error( "unknown symbol " + st.temporary, in );  // NOLINT
+            throw pegtl::parse_error( "unknown symbol " + st.temporary, in );
          }
          i->second = st.converted;
       }
@@ -91,10 +102,10 @@ namespace example
 
 }  // namespace example
 
-int main( int argc, char** argv )  // NOLINT
+int main( int argc, char** argv )  // NOLINT(bugprone-exception-escape)
 {
    for( int i = 1; i < argc; ++i ) {
-      pegtl::file_input<> in( argv[ i ] );
+      pegtl::file_input in( argv[ i ] );
       example::state st;
       pegtl::parse< example::grammar, example::action >( in, st );
       for( const auto& j : st.symbol_table ) {
@@ -103,3 +114,5 @@ int main( int argc, char** argv )  // NOLINT
    }
    return 0;
 }
+
+#endif
