@@ -1,4 +1,4 @@
-// Copyright (c) 2014-2020 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2022 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 // this include gives us _POSIX_MAPPED_FILES to test and mmap_input<> if it is set
@@ -9,24 +9,20 @@
 #include "test.hpp"
 #include "verify_file.hpp"
 
-namespace tao
+namespace TAO_PEGTL_NAMESPACE
 {
-   namespace TAO_PEGTL_NAMESPACE
+   void unit_test()
    {
-      void unit_test()
-      {
-         verify_file< mmap_input<> >();
-      }
+      verify_file< mmap_input<> >();
+   }
 
-   }  // namespace TAO_PEGTL_NAMESPACE
-
-}  // namespace tao
+}  // namespace TAO_PEGTL_NAMESPACE
 
 #include "main.hpp"
 
 #else
 
-int main( int, char** )
+int main()
 {
    return 0;
 }
